@@ -6,102 +6,77 @@
 // KIND, either express or implied. Please review the Licences for the specific language governing
 // permissions and limitations relating to use of the SAFE Network Software.
 
-use super::{new_auto_dump_db, Error, Result, ToDbKey};
-use pickledb::PickleDb;
+use super::{Error, Result, ToDbKey};
+use crate::types::utils::{deserialise, serialise};
 use serde::{de::DeserializeOwned, Serialize};
-
-use std::{
-    fmt::Debug,
-    marker::PhantomData,
-    path::{Path, PathBuf},
-};
-use tokio::fs;
+use sled::{Db, Tree};
+use std::{fmt::Debug, marker::PhantomData};
 use xor_name::XorName;
 
-const DB_EXTENSION: &str = ".db";
-
-/// Disk storage for transfers.
+/// Disk storage for events and similar.
+#[derive(Clone, Debug)]
 pub(crate) struct EventStore<TEvent: Debug + Serialize + DeserializeOwned> {
-    db: PickleDb,
-    db_path: PathBuf,
+    tree: Tree,
+    db_name: String,
     _phantom: PhantomData<TEvent>,
 }
 
-pub(crate) struct DeletableStore {
-    db_path: PathBuf,
-}
-
-impl DeletableStore {
-    pub(crate) async fn delete(&self) -> Result<()> {
-        fs::remove_file(self.db_path.as_path())
-            .await
-            .map_err(Error::Io)
-    }
-}
-
 impl<'a, TEvent: Debug + Serialize + DeserializeOwned> EventStore<TEvent>
 where
     TEvent: 'a,
 {
-    pub(crate) async fn new(id: XorName, db_dir: &Path) -> Result<Self> {
-        let db_name = format!("{}{}", id.to_db_key()?, DB_EXTENSION);
-        let db_path = db_dir.join(db_name.clone());
+    pub(crate) fn new(id: XorName, db: Db) -> Result<Self> {
+        let db_name = id.to_db_key()?;
+        let tree = db.open_tree(&db_name)?;
         Ok(Self {
-            db: new_auto_dump_db(db_dir, db_name).await?,
-            db_path,
+            tree,
+            db_name,
             _phantom: PhantomData::default(),
         })
     }
 
-    pub(crate) fn as_deletable(&self) -> DeletableStore {
-        DeletableStore {
-            db_path: self.db_path.clone(),
+    /// Get all events stored in db
+    pub(crate) fn get_all(&self) -> Result<Vec<TEvent>> {
+        let iter = self.tree.iter();
+
+        let mut events = vec![];
+        for (_, res) in iter.enumerate() {
+            let (key, val) = res?;
+            let db_key = String::from_utf8(key.to_vec())
+                .map_err(|_| Error::CouldNotParseDbKey(key.to_vec()))?;
+
+            let value: TEvent = deserialise(&val)?;
+            events.push((db_key, value))
         }
-    }
-
-    ///
-    pub(crate) fn get_all(&self) -> Vec<TEvent> {
-        let keys = self.db.get_all();
-
-        let mut events: Vec<(usize, TEvent)> = keys
-            .iter()
-            .filter_map(|key| {
-                let value = self.db.get::<TEvent>(key);
-                let key = key.parse::<usize>();
-                match value {
-                    Some(v) => match key {
-                        Ok(k) => Some((k, v)),
-                        _ => None,
-                    },
-                    None => None,
-                }
-            })
-            .collect();
 
         events.sort_by(|(key_a, _), (key_b, _)| key_a.partial_cmp(key_b).unwrap());
 
         let events: Vec<TEvent> = events.into_iter().map(|(_, val)| val).collect();
 
-        events
+        Ok(events)
     }
 
-    ///
+    /// append a new entry
     pub(crate) fn append(&mut self, event: TEvent) -> Result<()> {
-        let key = &self.db.total_keys().to_string();
-        if self.db.exists(key) {
+        let key = &self.tree.len().to_string();
+        if self.tree.get(key)?.is_some() {
             return Err(Error::InvalidOperation(format!(
                 "Key exists: {}. Event: {:?}",
                 key, event
             )));
         }
-        self.db.set(key, &event).map_err(Error::PickleDb)
+
+        let event = serialise(&event)?;
+        let _ = self.tree.insert(key, event).map_err(Error::Sled)?;
+
+        Ok(())
     }
 }
 
 #[cfg(test)]
 mod test {
     use super::EventStore;
-    use crate::node::Result;
+    use crate::node::{Error, Result};
     use crate::types::Token;
     use std::path::Path;
     use tempfile::tempdir;
@@ -111,12 +86,15 @@ mod test {
         let id = xor_name::XorName::random();
         let tmp_dir = tempdir()?;
         let db_dir = tmp_dir.into_path().join(Path::new(&"Token".to_string()));
-
-        let mut store = EventStore::new(id, db_dir.as_path()).await?;
+        let db = sled::open(db_dir).map_err(|error| {
+            trace!("Sled Error: {:?}", error);
+            Error::Sled(error)
+        })?;
+        let mut store = EventStore::<Token>::new(id, db)?;
 
         store.append(Token::from_nano(10))?;
 
-        let events = store.get_all();
+        let events = store.get_all()?;
         assert_eq!(events.len(), 1);
 
         match events.get(0) {
